<?php

namespace Drupal\iconify_icons\Element;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\Textfield;
use Drupal\Core\Url;

/**
 * Provides an entity autocomplete iconify icons form element.
 *
 * @see \Drupal\Core\Entity\Plugin\EntityReferenceSelection\DefaultSelection
 *
 * @FormElement("iconify_icons")
 */
class IconifyIcons extends Textfield {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    $info = parent::getInfo();
    $class = static::class;

    $info['#collections'] = '';
    $info['#settings'] = [];

    array_unshift($info['#process'], [$class, 'processIconifyIcons']);

    return $info;
  }

  /**
   * Adds entity autocomplete iconify icons functionality to a form element.
   *
   * @param array $element
   *   The form element to process.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   * @param array $complete_form
   *   The complete form structure.
   *
   * @return array
   *   The form element.
   */
  public static function processIconifyIcons(array &$element, FormStateInterface $form_state, array &$complete_form): array {
    $element['#attached'] = [
      'library' => [
        'iconify_icons/default',
      ],
    ];

    if (!isset($element['#attributes']['class'])) {
      $element['#attributes']['class'] = [];
    }
    $element['#attributes']['class'][] = 'iconify-icons-form-element';

    $element['#attributes']['data-autocomplete-url'] = Url::fromRoute('iconify_icons.autocomplete', [
      'collections' => $element['#collections'],
      'settings' => $element['#settings'],
    ])->toString();

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
    // Process the #default_value property.
    if ($input === FALSE && isset($element['#default_value']) && $element['#default_value']) {
      return static::getIconifyIconsDefaultValue($element['#default_value']);
    }

    return NULL;
  }

  /**
   * Formats the default values array for the iconify icons.
   *
   * @param string $icon
   *   An icon name and collection.
   *
   * @return false|string
   *   The tagify default values array. Associative array with at least the
   *   following keys:
   *   - 'icon':
   *     The svg icon.
   *   - 'label':
   *     The icon name and collection, IE: "Apple (openmoji)"
   *   - 'collection':
   *     The collection name, IE: openmoji.
   */
  public static function getIconifyIconsDefaultValue(string $icon) {
    // @todo get the needed attributes from $icon.
    $default_value[] = [
      'icon' => '',
      'label' => '',
      'collection' => '',
    ];

    return json_encode($default_value);
  }

}
